@@ -107,23 +107,6 @@ prepare_ask_primary (GQuark type)
 		return _("Enter password to unlock");
 }
 
-static const gchar*
-prepare_ask_check (GQuark type)
-{
-	/*
-	 * Yes this is unmaintainable and stupid, but is required 
-	 * for translations to work properly.
-	 */
-	if (type == GKR_PKIX_PRIVATE_KEY)
-		return _("Automatically unlock this private key when I log in.");
-	else if (type == GKR_PKIX_CERTIFICATE)
-		return _("Automatically unlock this certificate when I log in.");
-	else if (type == GKR_PKIX_PUBLIC_KEY)
-		return _("Automatically unlock this public key when I log in.");
-	else 
-		return _("Automatically unlock this when I log in");
-}
-
 static gchar*
 prepare_ask_secondary (GQuark type, const gchar *label)
 {
@@ -144,7 +127,7 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrconstid digest,
 {
 	GkrAskRequest *ask;
 	gchar *secondary;
-	gboolean ret;
+	gboolean ret = TRUE;
 	GkrPkIndex *index;
 	guint flags;
 	
@@ -168,7 +151,7 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrconstid digest,
 		return TRUE;
 	}
 	
-	if (!label) 
+	if (!label || !label[0]) 
 		label = import->import_label;
 		
 	/* Build up the prompt */
@@ -186,8 +169,6 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrconstid digest,
 	 */
 		
 	index = gkr_pk_storage_index (import->import_storage, loc);
-	if (gkr_pk_index_allows_secrets (index))
-		gkr_ask_request_set_check_option (ask, prepare_ask_check (type));
 		
 	/* Prompt the user */
 	gkr_ask_daemon_process (ask);
@@ -205,8 +186,6 @@ parser_ask_password (GkrPkixParser *parser, GQuark loc, gkrconstid digest,
 		*result = gkr_secure_strdup (ask->typed_password);
 		if (*result && strlen (*result) == 0)
 			*state = LAST_WAS_BLANK;
-		if (ask->checked) 
-			gkr_pk_index_set_secret (index, digest, ask->typed_password);
 	}
 	
 	g_object_unref (ask);
@@ -245,14 +224,14 @@ process_parsed (GkrPkImport *import, GQuark location, gkrconstid digest,
 	if (!gkr_pk_object_has_label (object) && import->import_label)
 		g_object_set (object, "label", import->import_label, NULL);
 	
+	import->import_objects = g_slist_prepend (import->import_objects, object);
+	g_object_weak_ref (G_OBJECT (object), object_disappeared, import);
+
 	if (created) {
 		gkr_pk_storage_store (import->import_storage, object, &pv->error);
 		g_object_unref (object);
 	}
 	
-	import->import_objects = g_slist_prepend (import->import_objects, object);
-	g_object_weak_ref (G_OBJECT (object), object_disappeared, import);
-	
 	return TRUE;
 }
 
@@ -525,10 +504,14 @@ gkr_pk_import_create (GkrPkManager* manager, GkrPkSession *session,
 		g_object_unref (*object);
 		*object = NULL;
 
-		if (err->domain == GKR_PKIX_PARSE_ERROR)
-			ret = CKR_DATA_INVALID;
-		else
+		if (err->domain == GKR_PKIX_PARSE_ERROR) {
+			if (err->code == GKR_PKIX_CANCELLED)
+				ret = CKR_FUNCTION_CANCELED;
+			else
+				ret = CKR_DATA_INVALID;
+		} else {
 			ret = CKR_FUNCTION_FAILED;
+		}
 
 		g_message ("couldn't import data: %s", err && err->message ? err->message : "");
 		g_clear_error (&err);
@@ -559,7 +542,7 @@ gkr_pk_import_perform (GkrPkImport *import, const guchar *data, gsize n_data, GE
 	
  	g_return_val_if_fail (GKR_IS_PK_IMPORT (import), FALSE);
  	
-	parser = gkr_pkix_parser_new ();
+	parser = gkr_pkix_parser_new (TRUE);
 	g_signal_connect (parser, "parsed-asn1", G_CALLBACK (parser_parsed_asn1), import);
 	g_signal_connect (parser, "parsed-sexp", G_CALLBACK (parser_parsed_sexp), import);
  	g_signal_connect (parser, "ask-password", G_CALLBACK (parser_ask_password), import);
@@ -572,12 +555,8 @@ gkr_pk_import_perform (GkrPkImport *import, const guchar *data, gsize n_data, GE
 
 	/* Check for import errors */
 	if (pv->error) {
-		if (*err) {
-			*err = pv->error;
-			pv->error = NULL;
-		}
-		
-		g_clear_error (&pv->error);
+		g_propagate_error (err, pv->error);
+		pv->error = NULL;
 		return FALSE;
 	}
 	
